@@ -1,8 +1,8 @@
 ;;; python-pytest.el --- helpers to run pytest -*- lexical-binding: t; -*-
 
 ;; Author: wouter bolsterlee <wouter@bolsterl.ee>
-;; Package-Version: 20250726.1726
-;; Package-Revision: ed2ecee09d1c
+;; Package-Version: 20260117.2218
+;; Package-Revision: 78b5ea1d19c7
 ;; Package-Requires: ((emacs "24.4") (dash "2.18.0") (transient "0.3.7") (s "1.12.0"))
 ;; Keywords: pytest, test, python, languages, processes, tools
 ;; URL: https://github.com/wbolster/emacs-python-pytest
@@ -187,7 +187,8 @@ don't support treesit should set this variable to nil."
     ("-q" "quiet" "--quiet")
     ("-s" "no output capture" "--capture=no")
     (python-pytest:-v)
-    (python-pytest:--l)]]
+    (python-pytest:--l)
+    (python-pytest:--durations)]]
   ["Selection, filtering, ordering"
    [(python-pytest:-k)
     (python-pytest:-m)
@@ -621,6 +622,13 @@ When present ON-REPLACEMENT is substituted, else OFF-REPLACEMENT is appended."
   :argument "--numprocesses="
   :choices '("auto" "0" "1" "2" "4" "8" "16"))
 
+(transient-define-argument python-pytest:--durations ()
+  :description "show durations"
+  :class 'transient-option
+  :key "--du"
+  :argument "--durations="
+  :choices '("0" "10" "20" "40"))
+
 (defun python-pytest--using-projectile ()
   "Returns t if projectile being used for project management."
   (or (eq python-pytest-preferred-project-manager 'projectile)
